<?php

/**
 * Notes:MSH：消息头段（Message Header Segment）
 * User: zyb
 * DateTime: 2023/3/31 16:19
 * @param $MSH
 * @return mixed
 */
function MSH($MSH)
{
    if (empty($MSH)) return (array());
    $mshMessage['Separator']          = $MSH->getField(1); //字段分隔符
    $mshMessage['EncodingCharacters'] = $MSH->getField(2); //代码字符
    $mshMessage['SendingApp']         = $MSH->getField(3); //发送程序
    $mshMessage['SendingFacility']    = $MSH->getField(4); //发送机构或设备
    $mshMessage['ReceiveApp']         = $MSH->getField(5); //接收程序名称[见字典MSH]
    $mshMessage['ReceiveFacility']    = $MSH->getField(6); //接收机构或设备
    $mshMessage['MessageDateTime']    = $MSH->getField(7); //消息时间
    $mshMessage['MessageType']        = $MSH->getField(9); //消息类型[见字典MSH]
    $mshMessage['MessageControlID']   = $MSH->getField(10); //消息控制ID
    $mshMessage['ProcessingID']       = $MSH->getField(11); //处理ID
    $mshMessage['VersionId']          = $MSH->getField(12); //版本ID
    $mshMessage['SequenceNumber']     = $MSH->getField(13); //序列号
    $mshMessage['CountryCode']        = $MSH->getField(17); //国籍代码

    return ($mshMessage);
}

/**
 * Notes:EVN：事件类型段（Event Type Segment）
 * User: zyb
 * DateTime: 2023/3/31 16:21
 * @param $message
 * @return mixed
 */
function EVN($message)
{
    if (empty($message)) return (array());

    $mshMessage['EventTypeCode']        = $message->getEventTypeCode(); //事件类型代码
    $mshMessage['RecordedDateTime']     = $message->getRecordedDateTime(); //事件记录时间
    $mshMessage['DateTimePlannedEvent'] = $message->getDateTimePlannedEvent(); //事件发生时间

    return ($mshMessage);
}

/**
 * Notes: 患者标识段（Patient Identification Segment）
 * User: zyb
 * DateTime: 2023/3/31 16:33
 * @param $message
 * @return mixed
 */
function PID($message)
{
    if (empty($message)) return (array());

    $mshMessage['IdentifierList']          = $message->getPatientIdentifierList(); //患者标识符[字典PID]
    $mshMessage['PatientName']             = $message->getPatientName(); //患者姓名
    $mshMessage['DateTimeOfBirth']         = $message->getDateTimeOfBirth(); //出生时间
    $mshMessage['Sex']                     = $message->getSex(); //性别[字典PID]
    $mshMessage['PatientAlias']            = $message->getPatientAlias(); //患者别名
    $mshMessage['PatientAddress']          = $message->getPatientAddress(); //患者地址
    $mshMessage['PhoneNumberHome']         = $message->getPhoneNumberHome(); //家庭电话
    $mshMessage['PhoneNumberBusiness']     = $message->getPhoneNumberBusiness(); //邮箱、工作电话、工作单位（公司名称）
    $mshMessage['PrimaryLanguage']         = $message->getPrimaryLanguage(); //母语
    $mshMessage['MaritalStatus']           = $message->getMaritalStatus(); //婚姻状况
    $mshMessage['Religion']                = $message->getReligion(); //宗教信仰
    $mshMessage['SSNNumber']               = $message->getSSNNumber(); //身份证号
    $mshMessage['DriversLicenseNumber']    = $message->getDriversLicenseNumber(); //驾驶证号
    $mshMessage['MothersIdentifier']       = $message->getMothersIdentifier(); //母亲标识号、婴儿标识 婴儿标识说明：0-不是婴儿，1-是婴儿
    $mshMessage['EthnicGroup']             = $message->getEthnicGroup(); //民族
    $mshMessage['BirthPlace']              = $message->getBirthPlace(); //出生地
    $mshMessage['MultipleBirthIndicator']  = $message->getMultipleBirthIndicator(); //多胞胎标识
    $mshMessage['BirthOrder']              = $message->getBirthOrder(); //多胞胎出生顺序
    $mshMessage['Citizenship']             = $message->getCitizenship(); //医保、职业、学历
    $mshMessage['Nationality']             = $message->getNationality(); //国籍
    $mshMessage['PatientDeathDateAndTime'] = $message->getPatientDeathDateAndTime(); //死亡时间
    $mshMessage['PatientDeathIndicator']   = $message->getPatientDeathIndicator(); //死亡标识 是否死亡：Y-是，N-否
    $mshMessage['LastUpdateDateTime']      = $message->getField(33); //创建/修改时间
    $mshMessage['SpeciesCode']             = $message->getField(35); //血型
    $mshMessage['ProductionClassCode']     = $message->getField(38); //年龄、体重、身高信息

    return ($mshMessage);
}

/**
 * Notes:NK1：患者联系人信息段（Next of Kin / Associated Parties Segment）
 * User: zyb
 * DateTime: 2023/3/31 17:15
 * @param $message
 * @return array
 */
function NK1($message)
{
    if (empty($message)) return (array());

    $mshMessage['Relationship']                  = $message->getRelationship(); //关系
    $mshMessage['OrganizationName']              = $message->getOrganizationName(); //工作单位
    $mshMessage['ContactPersonsName']            = $message->getContactPersonsName(); //联系人姓名
    $mshMessage['ContactPersonsTelephoneNumber'] = $message->getContactPersonsTelephoneNumber(); //联系人电话
    $mshMessage['ContactPersonsAddress']         = $message->getContactPersonsAddress(); //联系人地址

    return ($mshMessage);
}

/**
 * Notes:PV1：患者就诊信息段（Patient Visit Segment）
 * User: zyb
 * DateTime: 2023/4/3 11:14
 * @param $message
 * @return array
 */
function PV1($message)
{
    if (empty($message)) return (array());

    $mshMessage['SetID']                   = $message->getID(); //第几次就诊（或入院）
    $mshMessage['PatientClass']            = $message->getPatientClass(); //患者类别
    $mshMessage['AssignedPatientLocation'] = $message->getAssignedPatientLocation(); //患者位置
    $mshMessage['AdmissionType']           = $message->getAdmissionType(); //入院类型
    $mshMessage['PreAdmitNumber']          = $message->getPreAdmitNumber(); //就诊序号
    $mshMessage['AttendingDoctor']         = $message->getAttendingDoctor(); //主治医生~科主任
    $mshMessage['ReferringDoctor']         = $message->getReferringDoctor(); //助理医生/护士
    $mshMessage['ConsultingDoctor']        = $message->getConsultingDoctor(); //门诊挂号或咨询医生/护士
    $mshMessage['ReAdmissionIndicator']    = $message->getReAdmissionIndicator(); //再次入院标识
    $mshMessage['AdmitSource']          = $message->getAdmitSource(); //入院来源途径
    $mshMessage['VipIndicator']            = $message->getVipIndicator(); //VIP标识类型
    $mshMessage['AdmittingDoctor']         = $message->getAdmittingDoctor(); //入院医生/护士
    $mshMessage['PatientType']             = $message->getPatientType(); //门诊/住院就诊类型
    $mshMessage['FinancialClass']          = $message->getFinancialClass(); //就诊号码（门诊号、住院号或体检号等）
    $mshMessage['AdmitSource']             = $message->getAdmitSource(); //结算类型代码
    $mshMessage['CourtesyCode']            = $message->getCourtesyCode(); //挂号预约类型
    $mshMessage['ContractAmount']          = $message->getContractAmount(); //住院费用
    $mshMessage['ContractPeriod']          = $message->getContractPeriod(); //门诊费用
    $mshMessage['InterestCode']            = $message->getInterestCode(); //是否日间患者
    $mshMessage['TransferToBadDebtDate']   = $message->getTransferToBadDebtDate(); //创建/更新日期
    $mshMessage['BadDebtTransferAmount']   = $message->getBadDebtTransferAmount(); //个人承担费用（住院）
    $mshMessage['BadDebtRecoveryAmount']   = $message->getBadDebtRecoveryAmount(); //个人承担费用（门诊）
    $mshMessage['DeleteAccountDate']       = $message->getDeleteAccountDate(); //停止日期
    $mshMessage['DischargeDisposition'] = $message->getDischargeDisposition(); //就诊状态/出院方式或状态
    $mshMessage['AdmitDateTime']           = $message->getAdmitDateTime(); //就诊时间/入院时间
    $mshMessage['DischargeDateTime']       = $message->getDischargeDateTime(); //出院时间
    $mshMessage['TotalCharges']            = $message->getTotalCharges(); //总费用（￥）
    $mshMessage['TotalAdjustments']        = $message->getTotalAdjustments(); //个人承担总费用
    $mshMessage['TotalPayments']           = $message->getTotalPayments(); //总药用
    $mshMessage['AlternateVisitID']        = $message->getAlternateVisitID(); //就诊卡号
    $mshMessage['OtherHealthcareProvider'] = $message->getOtherHealthcareProvider(); //操作人员信息
    $mshMessage['BedStatus']               = $message->getBedStatus(); //在院标志、转归情况字典

    return ($mshMessage);
}

/**
 * Notes:PV2：患者就诊信息-附加段（Patient Visit - Additional Information Segment）
 * User: zyb
 * DateTime: 2023/4/3 11:58
 * @return array
 */
function PV2($message)
{
    if (empty($message)) return (array());

    $mshMessage['AccommodationCode']           = $message->getAccommodationCode(); //手术操作、治疗结果、根本死亡原因
    $mshMessage['AdmitReason']                 = $message->getAdmitReason(); //就诊原因
    $mshMessage['PatientValuablesLocation']    = $message->getPatientValuablesLocation(); //其他医学处置
    $mshMessage['ExpectedAdmitDateTime']       = $message->getExpectedAdmitDateTime(); //发病日期时间
    $mshMessage['ClinicOrganizationName']      = $message->getClinicOrganizationName(); //DRGs代码
    $mshMessage['PatientChargeAdjustmentCode'] = $message->getPatientChargeAdjustmentCode(); //中药使用类别
    $mshMessage['NewbornBabyIndicator']        = $message->getNewbornBabyIndicator(); //是否新生儿 Y-是，N-否
    $mshMessage['BabyDetainedIndicator']       = $message->getBabyDetainedIndicator(); //是否急诊留观患者
    $mshMessage['RecreationalDrugUseCode']     = $message->getRecreationalDrugUseCode(); //关键药物、关键药物用法、药物不良反应情况
    $mshMessage['ExpectedLOAEntryDateTime']    = $message->getField(48); //入区日期时间

    return ($mshMessage);
}

/**
 * Notes:SPM: 样本信息
 * User: zyb
 * DateTime: 2023/4/3 14:13
 * @param $message
 * @return array
 */
function SPM($message)
{
    if (empty($message)) return (array());

    $mshMessage['SpecimenID']                 = $message->getField(2); //样本编码（即样本号）及名称
    $mshMessage['SpecimenType']               = $message->getField(4); //样本类型、采样方法、采样部位、样本来源
    $mshMessage['SpecimenModifier']           = $message->getField(5); //微生物信息、标本状态描述
    $mshMessage['SpecimenCollectionDateTime'] = $message->getField(17); //采样时间
    $mshMessage['SpecimenReceivedDateTime']   = $message->getField(18); //接收时间

    return ($mshMessage);
}

/**
 * Notes:OBR:医嘱请求段（Observation Request Segment） 用于医嘱观察申请信息
 * User: zyb
 * DateTime: 2023/4/3 14:31
 * @param $message
 * @return array
 */
function OBR($message)
{
    if (empty($message)) return (array());

    $mshMessage['PlacerOrderNumber']                    = $message->getPlacerOrderNumber(); //申请序号/流水号
    $mshMessage['FillerOrderNumber']                    = $message->getFillerOrderNumber(); //条码号/项目索引号
    $mshMessage['UniversalServiceID']                   = $message->getUniversalServiceID(); //项目简介（说明）、总类、分类、检查部位
    $mshMessage['RequestedDatetime']                    = $message->getRequestedDatetime(); //申请时间
    $mshMessage['ObservationDateTime']                  = $message->getObservationDateTime(); //核收/审核(确认)时间
    $mshMessage['ObservationEndDateTime']               = $message->getObservationEndDateTime(); //开始/检查时间
    $mshMessage['CollectorIdentifier']                  = $message->getCollectorIdentifier(); //采样人及护士站
    $mshMessage['DangerCode']                           = $message->getDangerCode(); //开单时间、录入时间、报告打印次数
    $mshMessage['RelevantClinicalInfo']                 = $message->getRelevantClinicalInfo(); //病史诊断描述
    $mshMessage['SpecimenReceivedDateTime']             = $message->getSpecimenReceivedDateTime(); //签收时间
    $mshMessage['SpecimenSource']                       = $message->getSpecimenSource(); //1、样本类型/切口类型、样本信息、手术信息2、诊断信息4、操作信息5、麻醉信息
    $mshMessage['OrderingProvider']                     = $message->getOrderingProvider(); //申请人、开嘱(方)医生、开嘱(方)科室
    $mshMessage['Placerfield1']                         = $message->getPlacerfield1(); //申请科室代码
    $mshMessage['Placerfield2']                         = $message->getPlacerfield2(); //申请科室名称
    $mshMessage['FillerField1']                         = $message->getFillerField1(); //执行科室代码
    $mshMessage['FillerField2']                         = $message->getFillerField2(); //执行科室代码
    $mshMessage['ResultsRptStatusChngDateTime']         = $message->getResultsRptStatusChngDateTime(); //结束时间
    $mshMessage['ChargetoPractice']                     = $message->getChargetoPractice(); //收费信息
    $mshMessage['DiagnosticServSectID']                 = $message->getDiagnosticServSectID(); //医嘱性质（长期医嘱、临时医嘱、出院带药等） 请参见医嘱性质 该字段已移到ORC_18
    $mshMessage['ReasonForStudy']                       = $message->getReasonforStudy(); // 项目代码与名称 处方/医嘱类别【字典OBR】
    $mshMessage['PrincipalResultInterpreter']           = $message->getPrincipalResultInterpreter(); //执行/手术/检验医生、检查技师
    $mshMessage['AssistantResultInterpreter']           = $message->getAssistantResultInterpreter(); //审核(确认)者、核对者、核对时间、取消医嘱者、取消时间、计划时间
    $mshMessage['Technician']                           = $message->getTechnician(); //送检医生
    $mshMessage['ScheduledDateTime']                    = $message->getScheduledDateTime(); //采样时间
    $mshMessage['TransportLogisticsofCollectedSample']  = $message->getTransportLogisticsofCollectedSample(); //对应医嘱系统编码、对应医嘱系统名称、是否计算项目、是否显示、显示次序、是否组合项目
    $mshMessage['CollectorsComment']                    = $message->getCollectorsComment(); //病情描述 优先级(普通\紧急\优先)【字典OBR】
    $mshMessage['TransportArrangementResponsibility']   = $message->getTransportArrangementResponsibility(); //出报告医生、科室
    $mshMessage['TransportArranged']                    = $message->getTransportArranged(); //是否需要使用预防用抗菌药品
    $mshMessage['EscortRequired']                       = $message->getEscortRequired(); //是否异常
    $mshMessage['PlannedPatientTransportComment']       = $message->getPlannedPatientTransportComment(); //检查检验方法、单位、精度、是否修正（检查结果）、流程阶段
    $mshMessage['ProcedureCode']                        = $message->getField(44); //报告打印医生、时间
    $mshMessage['ProcedureCodeModifier']                = $message->getField(45); //作废信息、特殊检查标志、供体(或受体)信息、试剂厂商
    $mshMessage['FillerSupplementalServiceInformation'] = $message->getField(47); //停嘱医生和科室、停嘱时间

    return ($mshMessage);
}

/**
 * Notes:ORC: 医嘱通用信息
 * User: zyb
 * DateTime: 2023/4/3 14:58
 * @param $message
 * @return array
 */
function ORC($message)
{
    if (empty($message)) return (array());

    $mshMessage['OrderControl']                  = $message->getOrderControl(); //医嘱操作码
    $mshMessage['PlacerOrderNumber']             = $message->getPlacerOrderNumber(); //医嘱（处方）号、父医嘱号、子医嘱号
    $mshMessage['PlacerGroupNumber']             = $message->getPlacerGroupNumber(); //医嘱分组号、请参见收费或嘱托标志、医嘱确认标记
    $mshMessage['OrderStatus']                   = $message->getOrderStatus(); //医嘱状态（执行类型）
    $mshMessage['ResponseFlag']                  = $message->getResponseFlag(); //取消医嘱申请传  0 取消医嘱确认传  1
    $mshMessage['OrderingProvider']              = $message->getOrderingProvider(); //医嘱申请人员信息
    $mshMessage['EnterersLocation']              = $message->getEnterersLocation(); //患者入院信息
    $mshMessage['OrderEffectiveDateTime']        = $message->getOrderEffectiveDateTime(); //医嘱/处方(生效)日期
    $mshMessage['EnteringDevice']                = $message->getEnteringDevice(); //医嘱性质（长期医嘱、临时医嘱、出院带药等
    $mshMessage['AdvancedBeneficiaryNoticeCode'] = $message->getAdvancedBeneficiaryNoticeCode(); //医嘱部分DC相关类型
    $mshMessage['OrderingFacilityName']          = $message->getOrderingFacilityName(); //设备类型

    return ($mshMessage);
}

/**
 * Notes:OBX: 检查检验报告信息
 * User: zyb
 * DateTime: 2023/4/4 10:24
 * @param $message
 * @return array
 */
function OBX($message)
{
    if (empty($message)) return (array());

    $mshMessage['ValueType']                   = $message->getValueType(); //检查检验报告类型【见字典OBX】
    $mshMessage['ObservationIdentifier']       = $message->getObservationIdentifier(); //项目信息
    $mshMessage['ObservationSubId']            = $message->getObservationSubId(); //检查(验)条码报告号/流水号
    $mshMessage['ObservationValue']            = $message->getObservationValue(); //检查(诊断)结果
    $mshMessage['Units']                       = $message->getUnits(); //结果单位、结果描述、上下限、原始结果描述、原始检查结果值
    $mshMessage['ReferenceRange']              = $message->getReferenceRange(); //参值范围
    $mshMessage['AbnormalFlags']               = $message->getAbnormalFlags(); //异常标志【见字典OBX】
    $mshMessage['Probability']                 = $message->getProbability(); //检查检验小组索引
    $mshMessage['NatureOfAbnormalTest']        = $message->getNatureOfAbnormalTest(); //危急值标志1是；0否（默认）
    $mshMessage['ObserveResultStatus']         = $message->getObserveResultStatus(); //报告状态【见字典OBX】
    $mshMessage['DataLastObsNormalValues']     = $message->getDataLastObsNormalValues(); //报告时间
    $mshMessage['UserDefinedAccessChecks']     = $message->getUserDefinedAccessChecks(); //组合项目编号
    $mshMessage['DateTimeOfTheObservation']    = $message->getDateTimeOfTheObservation(); //检查时间
    $mshMessage['ProducersId']                 = $message->getProducersId(); //诊断疾病、疾病代码系统、报告标题、文件名
    $mshMessage['ObservationMethod']           = $message->getObservationMethod(); //检查印象、检查所见、是否阳性、备注、报告内容
    $mshMessage['EquipmentInstanceIdentifier'] = $message->getEquipmentInstanceIdentifier(); //设备类型、检查检验仪器索引、检查类型索引
    $mshMessage['DateTimeOfAnalysis']          = $message->getDateTimeOfAnalysis(); //审核时间

    return ($mshMessage);
}

/**
 * Notes:AL1 患者的过敏相关信息
 * User: zyb
 * DateTime: 2023/4/4 10:44
 */
function AL1()
{
    if (empty($MSH)) return (array());
    $mshMessage['AllergyType']                    = $MSH->getField(2); //过敏源类型
    $mshMessage['AllergyCodeMnemonicDescription'] = $MSH->getField(3); //过敏源
    $mshMessage['AllergyReaction']                = $MSH->getField(5); //记录创建/更新时间
    $mshMessage['IdentificationData']             = $MSH->getField(6); //确诊/停止日期

    return ($mshMessage);
}

/**
 * Notes:DG1 患者的诊断的相关信息
 * User: zyb
 * DateTime: 2023/4/4 14:44
 */
function DG1($message)
{
    if (empty($message)) return (array());

    $mshMessage['getID']                   = $message->getID(); //诊断次序
    $mshMessage['DiagnosisCodingMethod']   = $message->getDiagnosisCodingMethod(); //诊断序号
    $mshMessage['DiagnosisCode']           = $message->getDiagnosisCodeDG1(); //诊断代码及名称、中医诊断、中医症候
    $mshMessage['DiagnosisDescription']    = $message->getDiagnosisDescription(); //诊断描述
    $mshMessage['DiagnosisDateTime']       = $message->getDiagnosisDateTime(); //诊断时间
    $mshMessage['DiagnosisType']           = $message->getDiagnosisType(); //诊断类型[见DG1字典]
    $mshMessage['DiagnosticRelatedGroup']  = $message->getDiagnosticRelatedGroup(); //开诊断时的处方号、治疗依据描述、治疗方法
    $mshMessage['DRGGrouperReviewCode']    = $message->getDRGGrouperReviewCode(); //十二级诊断级别
    $mshMessage['OutlierType']             = $message->getOutlierType(); //诊断科室、治愈医生
    $mshMessage['OutlierDays']             = $message->getOutlierDays(); //治疗天数
    $mshMessage['GrouperVersionAndType']   = $message->getGrouperVersionAndType(); //治愈情况
    $mshMessage['DiagnosisPriority']       = $message->getDiagnosisPriority(); //即诊断类别或级别[见DG1字典]
    $mshMessage['DiagnosingClinician']     = $message->getDiagnosingClinician(); //诊断医生
    $mshMessage['DiagnosisClassification'] = $message->getDiagnosisClassification(); //诊断性质[见DG1字典]
    $mshMessage['AttestationDateTime']     = $message->getAttestationDateTime(); //治愈时间

    return ($mshMessage);
}

/**
 * Notes:FT1 费用信息
 * User: zyb
 * DateTime: 2023/4/4 16:11
 * @param $message
 * @return array
 */
function FT1($message)
{
    if (empty($message)) return (array());

    $mshMessage['TransactionID']           = $message->getField(2); //收费单号
    $mshMessage['TransactionBatchID']      = $message->getField(3); //处方关联号
    $mshMessage['TransactionDate']         = $message->getField(4); //收费时间及退费时间
    $mshMessage['TransactionType']         = $message->getField(6); //处理类型[见FT1字典]
    $mshMessage['TransactionCode']         = $message->getField(7); //退费标记及原退费单号
    $mshMessage['TransactionExtendAmount'] = $message->getField(11); //收费金额
    $mshMessage['TransactionUnitAmount']   = $message->getField(12); //药品单价
    $mshMessage['DepartmentCode']          = $message->getField(13); //处方科室
    $mshMessage['OrderedByCode']           = $message->getField(21); //处方医生
    $mshMessage['ProcedureCode']           = $message->getField(25); //药品信息
    $mshMessage['ProcedureCodeModifier']   = $message->getField(26); //医保类型
    $mshMessage['FT1-14']                  = $message->getField(14); //收据项目编码^核算项目编码
    $mshMessage['FT1-15']                  = $message->getField(15); //汇总日期
    $mshMessage['FT1-8']                   = $message->getField(8); //药品非药品分类
    $mshMessage['FT1-17']                  = $message->getField(17); //医保收费等级
    $mshMessage['FT1-9']                   = $message->getField(9); //手术室费用标志
    $mshMessage['FT1-10']                  = $message->getField(10); //麻醉室费用标志
    $mshMessage['FT1-16']                  = $message->getField(16); //费用记录序号
    $mshMessage['FT1-18']                  = $message->getField(18); //项目医保自费标志
    $mshMessage['FT1-19']                  = $message->getField(19); //手术单号

    return ($mshMessage);
}

/**
 * Notes:RXA 处方医嘱等执行情况
 * User: zyb
 * DateTime: 2023/4/7 9:00
 */
function RXA($message)
{
    if (empty($message)) return (array());

    $mshMessage['GiveSubIDCounter']              = $message->getField(1); //固定值0
    $mshMessage['AdministrationSubIDCounter']    = $message->getField(2); //次序值
    $mshMessage['DateTimeStartOfAdministration'] = $message->getField(3); //开始时间
    $mshMessage['DateTimeEndOfAdministration']   = $message->getField(4); //结束时间
    $mshMessage['AdministeredCode']              = $message->getField(5); //药品信息
    $mshMessage['AdministeredAmount']            = $message->getField(6); //用量
    $mshMessage['AdministeredUnits']             = $message->getField(7); //用量单位
    $mshMessage['administeredDosageForm']        = $message->getField(8); //剂型、实际剂量、执行剂量不符原因
    $mshMessage['AdministeredNotes']             = $message->getField(9); //执行用法、执行方法不符原因、计划执行时间、执行时间不符原因
    $mshMessage['AdministeringProvider']         = $message->getField(10); //执行人
    $mshMessage['AdministeredAtLocation']        = $message->getField(11); //Facility - NamespaceID - 科室代码; Facility - UniversalID - 科室名称; Floor - 病区代码; StreetAddress - 病区名称
    $mshMessage['SubstanceLotNumber']            = $message->getField(15); //手术单号
    $mshMessage['CompletionStatus']              = $message->getField(20); //完成情况[见字典RXA]
    $mshMessage['ActionCode']                    = $message->getField(21); //执行代码[见字典RXA]


    return ($mshMessage);
}

/**
 * Notes: RXO 要描述药品/治疗信息
 * User: zyb
 * DateTime: 2023/4/7 10:05
 * @param $message
 * @return array
 */
function RXO($message)
{
    if (empty($message)) return (array());

    $mshMessage['RequestedGiveCode']          = $message->getField(1); //处方医嘱序号、处方医嘱类型[见字典RXO]
    $mshMessage['RequestedGiveUnits']         = $message->getField(4); //是否预防用药、是否手术用药、是否出院带药、抗菌药标志、注射剂标志、出院带药标志
    $mshMessage['RequestedDosageForm']        = $message->getField(5); //停嘱医生及科室、停嘱时间
    $mshMessage['PPTI']                       = $message->getField(6); //药品规格、厂家、机器号（摆药机）、小组标志（摆药机）、紧急类别代码、紧急类别名称
    $mshMessage['PAI']                        = $message->getField(7); //开药医生及科室、录入者
    $mshMessage['AllowSubstitutions']         = $message->getField(9); //是否电子处方/医嘱
    $mshMessage['RequestedDosageCode']        = $message->getField(10); //医保、包装类型
    $mshMessage['RequestedDispenseAmount']    = $message->getField(11); //单价（单位：元）
    $mshMessage['RequestedDispenseUnits']     = $message->getField(12); //药品代码、名称及用药嘱托
    $mshMessage['NumberOfRefills']            = $message->getField(13); //中草药剂量
    $mshMessage['OrderIngProviderDEANumber']  = $message->getField(14); //与收费信息关联号
    $mshMessage['IDNumber']                   = $message->getField(15); //与发药信息关联号、执行时间、确认(审核)时间、确认(审核)人、责任医生
    $mshMessage['NeedsHumanReview']           = $message->getField(16); //医嘱/处方状态
    $mshMessage['RequestedGivePerTimeUnit']   = $message->getField(17); //开处方/医嘱时间
    $mshMessage['RequestedGiveStrength']      = $message->getField(18); //服药天数
    $mshMessage['RequestedGiveStrengthUnits'] = $message->getField(19); //单日服用次数、频次代码和名称、频次描述、剂型信息
    $mshMessage['Indication']                 = $message->getField(20); //开嘱病区、停嘱病区
    $mshMessage['RequestedGiveRateUnits']     = $message->getField(22); //每次剂量、每次数量、计划数量
    $mshMessage['RequestedGiveRateUnits']     = $message->getField(21); //停医嘱当天计费标准 0表示不计费，1表示停医嘱当天也算一次费用，默认0
    $mshMessage['TotalDailyDose']             = $message->getField(23); //总剂量/数量、单包装剂量、单片剂量
    $mshMessage['SupplementaryCode']          = $message->getField(24); //用药时间及说明等


    return ($mshMessage);
}

/**
 * Notes: RXD 描述药品/治疗分发信息
 * User: zyb
 * DateTime: 2023/4/7 10:06
 * @param $message
 * @return array
 */
function RXD($message)
{
    if (empty($message)) return (array());

    $mshMessage['DispenseSubIDCounter']     = $message->getField(1); //发药单号
    $mshMessage['DispenseGiveCode']         = $message->getField(2); //退药信息
    $mshMessage['DateTimeDispensed']        = $message->getField(3); //发药/退药时间
    $mshMessage['ActualDispenseAmount']     = $message->getField(4); //发药数量
    $mshMessage['ActualDispenseUnits']      = $message->getField(5); //发药单位
    $mshMessage['PrescriptionNumber']       = $message->getField(7); //与处方的关联号/ 医嘱唯一号
    $mshMessage['NumberOfRefillsRemaining'] = $message->getField(8); //发药药费金额
    $mshMessage['DispenseNotes']            = $message->getField(9); //药品单价
    $mshMessage['DispensingProvider']       = $message->getField(10); //发药药师
    $mshMessage['PharmacyTreatmentSupper']  = $message->getField(15); //审核调配药师
    $mshMessage['SupplementaryCode']        = $message->getField(25); //发药/接收科室
    $mshMessage['InitiatingLocation']       = $message->getField(26); //发药药房/接收病区及床位号

    return ($mshMessage);
}

/**
 * Notes:RXR 药品/治疗流程信息
 * User: zyb
 * DateTime: 2023/4/7 11:22
 * @param $message
 * @return mixed
 */
function RXR($message)
{

    if (empty($message)) return (array());

    $mshMessage['Route']              = $message->getField(1); //途径代码及名称[见字典RXR]
    $mshMessage['site']               = $message->getField(2); //使用部位[见字典RXR]
    $mshMessage['Method']             = $message->getField(4); //使用方法[见字典RXR]
    $mshMessage['RoutingInstruction'] = $message->getField(5); //用药/治疗目的、原因
    $mshMessage['RXR_3']              = $message->getField(3); //药品皮试结果

    return $mshMessage;
}

/**
 * Notes: QRD 放置各项查询条件
 * User: zyb
 * DateTime: 2023/4/7 11:45
 * @param $message
 * @return array
 */
function QRD($message)
{
    if (empty($message)) return (array());

    $mshMessage['QueryDateTime']          = $message->getField(1); //查询日期
    $mshMessage['QueryFormatCode']        = $message->getField(2); //查询格式编码
    $mshMessage['QueryPriority']          = $message->getField(3); //查询优先度
    $mshMessage['QueryID']                = $message->getField(4); //查询ID（由发起者生成）
    $mshMessage['QuantityLimitedRequest'] = $message->getField(7); //数量单位
    $mshMessage['WhoSubjectFilter']       = $message->getField(8); //患者标识符
    $mshMessage['WhatSubjectFilter']      = $message->getField(9); //主题类别，申请单号
    $mshMessage['DepartCode']             = $message->getField(10); //部门
    $mshMessage['DataCodeValue']          = $message->getField(11); //项目代码

    return $mshMessage;
}

/**
 * Notes:NTE:OSQ^Q06消息
 * User: zyb
 * DateTime: 2023/4/12 16:16
 * @param $message
 * @return array
 */
function NTE($message)
{
    if (empty($message)) return (array());

    $mshMessage['Comment']     = $message->getComment(); //就诊类型
    $mshMessage['CommentType'] = $message->getCommentType(); //病房及医生信息

    return $mshMessage;
}

/**
 * Notes:QRF
 * User: zyb
 * DateTime: 2023/4/12 16:21
 * @param $message
 * @return array
 */
function QRF($message)
{

    if (empty($message)) return (array());

    $mshMessage['WhereSubjectFilter'] = $message->getField(1); //主题筛选

    return $mshMessage;
}

/**
 * Notes: RGS 段行为码
 * User: zyb
 * DateTime: 2023/4/12 16:25
 * @param $message
 * @return array
 */
function RGS($message)
{
    if (empty($message)) return (array());

    $mshMessage['SegmentActionCode'] = $message->getField(2); //段行为码 A-新增 U-更新 D-删除

    return $mshMessage;
}

/**
 * Notes:SCH
 * User: zyb
 * DateTime: 2023/4/12 16:26
 * @param $message
 * @return array
 */
function SCH($message)
{
    if (empty($message)) return (array());

    $mshMessage['PlacerAppointmentID']       = $message->getPlacerAppointmentID(); //手术申请号(HIS/EMR等
    $mshMessage['FillerAppointmentID']       = $message->getFillerAppointmentID(); //手术申请号(手麻)
    $mshMessage['AppointmentTimingQuantity'] = $message->getAppointmentTimingQuantity(); //申请时间、预约手术安排时间、记录生成时间
    $mshMessage['EnteredbyPerson']           = $message->getEnteredbyPerson(); //录入者IDNumber - 人员代码FamilyName-Surname - 人员姓名

    return $mshMessage;
}

/**
 * Notes:AIS 手术信息
 * User: zyb
 * DateTime: 2023/4/12 16:32
 */
function AIS($message)
{
    if (empty($message)) return (array());

    $mshMessage['SegmentActionCode']        = $message->getField(2); //段行为码 A-新增 U-更新 D-删除
    $mshMessage['UniversalServiceID']       = $message->getField(3); //手术项目信息Identifier - 手术代码Text - 手术名称
    $mshMessage['StartDateTime']            = $message->getField(4); //手术时间（开始）
    $mshMessage['StartDateTimeOffsetUnits'] = $message->getField(6); //术中失血量、术中输血量、是否有植入物、手术时间（结束）
    $mshMessage['DurationUnits']            = $message->getField(8); //I类切口抗菌药物、预防药物情况
    $mshMessage['FillerStatusCode']         = $message->getField(10); //择期急诊、费用类型
    $mshMessage['PlacerSupplemental']       = $message->getField(11); //手术信息其他参数[见字典AIS]

    return $mshMessage;
}

/**
 * Notes:AIL 场所资源信息
 * User: zyb
 * DateTime: 2023/4/12 16:46
 * @param $message
 * @return array
 */
function AIL($message)
{
    if (empty($message)) return (array());

    $mshMessage['SegmentActionCode']  = $message->getField(2); //段行为码 A-新增 U-更新 D-删除
    $mshMessage['LocationResourceID'] = $message->getField(3); //场所资源信息PointOfCare - 手术室代码Room - 手术间号

    return $mshMessage;
}

/**
 * Notes:AIP 手术人员信息
 * User: zyb
 * DateTime: 2023/4/12 16:47
 * @param $message
 * @return array
 */
function AIP($message)
{
    if (empty($message)) return (array());

    $mshMessage['SegmentActionCode'] = $message->getField(2); //段行为码 A-新增 U-更新 D-删除
    $mshMessage['PersonResourceID']  = $message->getField(3); //手术人员信息 IDNumber-人员代码FamilyName-人员姓名AssigningFacility-NamespaceID - 所属科室代码AssigningFacility-UniversalID - 所属科室名称
    $mshMessage['ResourceRole']      = $message->getField(4); //角色信息 Identifier - 角色代码Text - 角色名称

    return $mshMessage;
}

/**
 * Notes:ARQ
 * User: zyb
 * DateTime: 2023/4/12 16:59
 */
function ARQ($message)
{
    if (empty($message)) return (array());

    $mshMessage['PlacerAppointmentID']        = $message->getField(1); //手术申请号(HIS)
    $mshMessage['OccurrenceNumber']           = $message->getField(3); //台次（接台号）
    $mshMessage['RequestedStarDateTimeRange'] = $message->getField(11); //手术登记时间^手术预约时间

    return $mshMessage;
}

/**
 * Notes: MSA 应答结果的相关信息
 * User: zyb
 * DateTime: 2023/4/12 17:08
 * @param $message
 * @return array
 */
function MSA($message)
{
    if (empty($message)) return (array());

    $mshMessage['AcknowledgementCode']    = $message->getField(1); //应答标志
    $mshMessage['MessageControlID']       = $message->getField(2); //消息控制ID
    $mshMessage['TextMessage_DEPRECATED'] = $message->getField(3); //错误信息/描述信息

    return $mshMessage;

}

/**
 * Notes: IN1 患者保险相关信息
 * User: zyb
 * DateTime: 2023/4/13 10:54
 * @param $message
 * @return array
 */
function IN1($message)
{
    if (empty($message)) return (array());

    $mshMessage['InsurancePlanID']      = $message->getInsurancePlanID(); //社会保险险种类型代码和名称Identifier - 社会保险险种类型代码Text - 社会保险险种类型名称
    $mshMessage['InsuredsGroupEmpID']   = $message->getInsuredsGroupEmpID(); //医疗参保人员类别代码
    $mshMessage['InsuredsGroupEmpName'] = $message->getInsuredsGroupEmpName(); //医疗参保人员类别名称

    return $mshMessage;
}

function INSURANCE($message)
{
    if (empty($message)) return (array());

    $mshMessage['InsurancePlanID']      = $message->getInsurancePlanID(); //社会保险险种类型代码和名称Identifier - 社会保险险种类型代码Text - 社会保险险种类型名称
    $mshMessage['InsuredsGroupEmpID']   = $message->getInsuredsGroupEmpID(); //医疗参保人员类别代码
    $mshMessage['InsuredsGroupEmpName'] = $message->getInsuredsGroupEmpName(); //医疗参保人员类别名称

    return $mshMessage;
}


